﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Chbl.DAL;
using Chbl.Models;

namespace Chbl.Controllers.AdminRole
{
    [Authorize(Roles = "admin")]
    public class AdminPlayerController : Controller
    {
        private readonly ChblDb _db;

        public AdminPlayerController(ChblDb db)
        {
            _db = db;
        }
        //
        // GET: /AdminPlayer/

        public ViewResult Index()
        {
            var players = _db.Players.Include(p => p.Member);
            return View(players.ToList());
        }

        //
        // GET: /AdminPlayer/Details/5

        public ViewResult Details(int id)
        {
            Player player = _db.Players.Find(id);
            return View(player);
        }

        //
        // GET: /AdminPlayer/Create

        public ActionResult Create()
        {
            var player = new Player
                             {
                                 Member = new Member { BirthDate = new DateTime(1900, 1,1)}
                             };
            return View(player);
        } 

        //
        // POST: /AdminPlayer/Create

        [HttpPost]
        public ActionResult Create(Player player)
        {
            if (ModelState.IsValid)
            {
                _db.Members.Add(player.Member);
                _db.Players.Add(player);
                _db.SaveChanges();
                return RedirectToAction("Index");  
            }

            ViewBag.MemberId = new SelectList(_db.Members, "MemberId", "Fio", player.MemberId);
            return View(player);
        }
        
        //
        // GET: /AdminPlayer/Edit/5
 
        public ActionResult Edit(int id)
        {
            Player player = _db.Players.Find(id);
            return View(player);
        }

        //
        // POST: /AdminPlayer/Edit/5

        [HttpPost]
        public ActionResult Edit(Player player)
        {
            if (ModelState.IsValid)
            {
                _db.Entry(player.Member).State = EntityState.Modified;
                _db.SaveChanges();
                _db.Entry(player).State = EntityState.Modified;
                _db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(player);
        }

        //
        // GET: /AdminPlayer/Delete/5
 
        public ActionResult Delete(int id)
        {
            Player player = _db.Players.Find(id);
            return View(player);
        }

        //
        // POST: /AdminPlayer/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Player player = _db.Players.Find(id);
            _db.Players.Remove(player);
            _db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            _db.Dispose();
            base.Dispose(disposing);
        }
    }
}