﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Chbl.DAL;
using Chbl.Models;

namespace Chbl.Controllers.AdminRole
{
    [Authorize(Roles = "admin")]
    public class AdminSeasonController : Controller
    {
        private readonly ChblDb _db;

        public AdminSeasonController(ChblDb db)
        {
            _db = db;
        }
        //
        // GET: /AdminSeason/

        public ViewResult Index()
        {
            return View(_db.Seasons.ToList());
        }

        //
        // GET: /AdminSeason/Details/5

        public ViewResult Details(int id)
        {
            Season season = _db.Seasons.Find(id);
            return View(season);
        }

        //
        // GET: /AdminSeason/Create

        public ActionResult Create()
        {
            return View();
        } 

        //
        // POST: /AdminSeason/Create

        [HttpPost]
        public ActionResult Create(Season season)
        {
            if (ModelState.IsValid)
            {
                _db.Seasons.Add(season);
                _db.SaveChanges();
                return RedirectToAction("Index");  
            }

            return View(season);
        }
        
        //
        // GET: /AdminSeason/Edit/5
 
        public ActionResult Edit(int id)
        {
            Season season = _db.Seasons.Find(id);
            return View(season);
        }

        //
        // POST: /AdminSeason/Edit/5

        [HttpPost]
        public ActionResult Edit(Season season)
        {
            if (ModelState.IsValid)
            {
                _db.Entry(season).State = EntityState.Modified;
                _db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(season);
        }

        //
        // GET: /AdminSeason/Delete/5
 
        public ActionResult Delete(int id)
        {
            Season season = _db.Seasons.Find(id);
            return View(season);
        }

        //
        // POST: /AdminSeason/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Season season = _db.Seasons.Find(id);
            _db.Seasons.Remove(season);
            _db.SaveChanges();
            return RedirectToAction("Index");
        }


        protected override void Dispose(bool disposing)
        {
            _db.Dispose();
            base.Dispose(disposing);
        }
    }
}