﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Chbl.DAL;
using Chbl.Models;
using Chbl;

namespace Chbl.Controllers.AdminRole
{
    [Authorize(Roles = "admin")]
    public class AdminSettingsController : Controller
    {
        private readonly ChblDb _db;

        public AdminSettingsController(ChblDb chblDb)
        {
            _db = chblDb;
        }
        //
        // GET: /AdminSettings/

        public ViewResult Index()
        {
            return View(_db.Settings.ToList());
        }

        //
        // GET: /AdminSettings/Details/5

        public ViewResult Details(int id)
        {
            Settings settings = _db.Settings.Find(id);
            return View(settings);
        }

        //
        // GET: /AdminSettings/Create

        public ActionResult Create()
        {
            return View();
        } 

        //
        // POST: /AdminSettings/Create

        [HttpPost]
        public ActionResult Create(Settings settings)
        {
            if (ModelState.IsValid)
            {
                _db.Settings.Add(settings);
                _db.SaveChanges();
                return RedirectToAction("Index");  
            }

            return View(settings);
        }
        
        //
        // GET: /AdminSettings/Edit/5
 
        public ActionResult Edit(int id)
        {
            Settings settings = _db.Settings.Find(id);
            return View(settings);
        }

        //
        // POST: /AdminSettings/Edit/5

        [HttpPost]
        public ActionResult Edit(Settings settings)
        {
            if (ModelState.IsValid)
            {
                _db.Entry(settings).State = EntityState.Modified;
                _db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(settings);
        }

        //
        // GET: /AdminSettings/Delete/5
 
        public ActionResult Delete(int id)
        {
            Settings settings = _db.Settings.Find(id);
            return View(settings);
        }

        //
        // POST: /AdminSettings/Delete/5

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(int id)
        {            
            Settings settings = _db.Settings.Find(id);
            _db.Settings.Remove(settings);
            _db.SaveChanges();
            return RedirectToAction("Index");
        }

        protected override void Dispose(bool disposing)
        {
            _db.Dispose();
            base.Dispose(disposing);
        }
    }
}